==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextServicesSupport__24BCSSProxyServiceProvider.h <==
// public class java.beans.beancontext.BeanContextServicesSupport$BCSSProxyServiceProvider

// class file dependencies
// @dep_class 234ca7ae50d55c31 java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider_H_
#define _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object;
struct _jc_java_beans_beancontext_BeanContextServices$object;
struct _jc_java_beans_beancontext_BeanContextServicesSupport$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object;

typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$_init$a7185a17cd67eb90(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_java_beans_beancontext_BeanContextServicesSupport$object *);

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$getCurrentServiceSelectors$931813c2bacfb682(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$getService$3af106dd0294bbba(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$releaseService$2e0839e266557ea5(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$serviceRevoked$d2c1bb5e41123586(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$getCurrentServiceSelectors$931813c2bacfb682;
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$getService$3af106dd0294bbba;
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$releaseService$2e0839e266557ea5;
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$serviceRevoked$d2c1bb5e41123586;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods {
	struct _jc_object	*(*getCurrentServiceSelectors$931813c2bacfb682)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
	struct _jc_java_lang_Object$object	*(*getService$3af106dd0294bbba)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Object$object *);
	void	(*releaseService$2e0839e266557ea5)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*serviceRevoked$d2c1bb5e41123586)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods	java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs {
	struct _jc_java_beans_beancontext_BeanContextServicesSupport$object	*this;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs {
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs	java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs	java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object {
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextServicesSupport__24BCSSProxyServiceProvider.h <==
// public class java.beans.beancontext.BeanContextServicesSupport$BCSSProxyServiceProvider

// class file dependencies
// @dep_class 234ca7ae50d55c31 java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider_H_
#define _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object;
struct _jc_java_beans_beancontext_BeanContextServices$object;
struct _jc_java_beans_beancontext_BeanContextServicesSupport$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object;

typedef struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$fields_struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$_init$a7185a17cd67eb90(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_java_beans_beancontext_BeanContextServicesSupport$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$getCurrentServiceSelectors$931813c2bacfb682(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$getService$3af106dd0294bbba(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$releaseService$2e0839e266557ea5(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method$serviceRevoked$d2c1bb5e41123586(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$getCurrentServiceSelectors$931813c2bacfb682;
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$getService$3af106dd0294bbba;
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$releaseService$2e0839e266557ea5;
extern _jc_method _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$method_info$serviceRevoked$d2c1bb5e41123586;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods {
	struct _jc_object	*(*getCurrentServiceSelectors$931813c2bacfb682)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getService$3af106dd0294bbba)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*releaseService$2e0839e266557ea5)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*serviceRevoked$d2c1bb5e41123586)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object *, struct _jc_java_beans_beancontext_BeanContextServiceRevokedEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vmethods	java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs {
	struct _jc_java_beans_beancontext_BeanContextServicesSupport$object	*this;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs {
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_refs	java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$sub_nonrefs	java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$object {
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$vtype _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextServicesSupport__24BCSSProxyServiceProvider_H_ */
